@@ -3,7 +3,7 @@
 #
 #  (C) Paul Evans, 2013-2022 -- leonerd@leonerd.org.uk
 
-package Devel::MAT::SV 0.46;
+package Devel::MAT::SV 0.47;
 
 use v5.14;
 use warnings;
@@ -18,7 +18,7 @@ use constant immortal => 0;
 
 use Struct::Dumb 0.07 qw( readonly_struct );
 readonly_struct Reference => [qw( name strength sv )];
-readonly_struct Magic     => [qw( type obj ptr )];
+readonly_struct Magic     => [qw( type obj ptr vtbl )];
 
 =head1 NAME
 
@@ -206,6 +206,7 @@ as struct fields:
    $type = $magic->type
    $sv = $magic->obj
    $sv = $magic->ptr
+   $ptr = $magic->vtbl
 
 =cut
 
@@ -216,8 +217,8 @@ sub magic
 
    my $df = $self->df;
    return map {
-      my ( $type, undef, $obj_at, $ptr_at ) = @$_;
-      Magic( $type, $df->sv_at( $obj_at ), $df->sv_at( $ptr_at ) );
+      my ( $type, undef, $obj_at, $ptr_at, $vtbl_ptr ) = @$_;
+      Magic( $type, $df->sv_at( $obj_at ), $df->sv_at( $ptr_at ), $vtbl_ptr );
    } @$magic;
 }
 
@@ -286,9 +287,9 @@ sub rootname
 sub more_magic
 {
    my $self = shift;
-   my ( $type, $flags, $obj_at, $ptr_at ) = @_;
+   my ( $type, $flags, $obj_at, $ptr_at, $vtbl_ptr ) = @_;
 
-   push @{ $self->{magic} }, [ $type => $flags, $obj_at, $ptr_at ];
+   push @{ $self->{magic} }, [ $type => $flags, $obj_at, $ptr_at, $vtbl_ptr ];
 }
 
 sub _more_annotations
@@ -460,7 +461,7 @@ boolean true and false. They are
 
 =cut
 
-package Devel::MAT::SV::Immortal 0.46;
+package Devel::MAT::SV::Immortal 0.47;
 use base qw( Devel::MAT::SV );
 use constant immortal => 1;
 use constant basetype => "SV";
@@ -473,12 +474,12 @@ sub new {
 }
 sub _outrefs { () }
 
-package Devel::MAT::SV::UNDEF 0.46;
+package Devel::MAT::SV::UNDEF 0.47;
 use base qw( Devel::MAT::SV::Immortal );
 sub desc { "UNDEF" }
 sub type { "UNDEF" }
 
-package Devel::MAT::SV::YES 0.46;
+package Devel::MAT::SV::YES 0.47;
 use base qw( Devel::MAT::SV::Immortal );
 sub desc { "YES" }
 sub type { "SCALAR" }
@@ -491,7 +492,7 @@ sub pv { "1" }
 sub rv { undef }
 sub is_weak { '' }
 
-package Devel::MAT::SV::NO 0.46;
+package Devel::MAT::SV::NO 0.47;
 use base qw( Devel::MAT::SV::Immortal );
 sub desc { "NO" }
 sub type { "SCALAR" }
@@ -504,7 +505,7 @@ sub pv { "0" }
 sub rv { undef }
 sub is_weak { '' }
 
-package Devel::MAT::SV::Unknown 0.46;
+package Devel::MAT::SV::Unknown 0.47;
 use base qw( Devel::MAT::SV );
 __PACKAGE__->register_type( 0xff );
 
@@ -512,7 +513,7 @@ sub desc { "UNKNOWN" }
 
 sub _outrefs {}
 
-package Devel::MAT::SV::GLOB 0.46;
+package Devel::MAT::SV::GLOB 0.47;
 use base qw( Devel::MAT::SV );
 __PACKAGE__->register_type( 1 );
 use constant $CONSTANTS;
@@ -698,7 +699,7 @@ sub _more_saved
    push @{ $self->{saved} }, [ $slot => $addr ];
 }
 
-package Devel::MAT::SV::SCALAR 0.46;
+package Devel::MAT::SV::SCALAR 0.47;
 use base qw( Devel::MAT::SV );
 __PACKAGE__->register_type( 2 );
 use constant $CONSTANTS;
@@ -859,7 +860,7 @@ sub _outrefs
    return @outrefs;
 }
 
-package Devel::MAT::SV::REF 0.46;
+package Devel::MAT::SV::REF 0.47;
 use base qw( Devel::MAT::SV );
 __PACKAGE__->register_type( 3 );
 use constant $CONSTANTS;
@@ -950,7 +951,7 @@ sub _outrefs
    return @outrefs;
 }
 
-package Devel::MAT::SV::BOOL 0.46;
+package Devel::MAT::SV::BOOL 0.47;
 use base qw( Devel::MAT::SV::SCALAR );
 
 sub type { return "BOOL" }
@@ -962,7 +963,7 @@ sub desc
    return "BOOL(NO)";
 }
 
-package Devel::MAT::SV::ARRAY 0.46;
+package Devel::MAT::SV::ARRAY 0.47;
 use base qw( Devel::MAT::SV );
 __PACKAGE__->register_type( 4 );
 use constant $CONSTANTS;
@@ -1118,7 +1119,7 @@ sub _outrefs
    return @outrefs;
 }
 
-package Devel::MAT::SV::PADLIST 0.46;
+package Devel::MAT::SV::PADLIST 0.47;
 # Synthetic type
 use base qw( Devel::MAT::SV::ARRAY );
 use constant type => "PADLIST";
@@ -1166,7 +1167,7 @@ sub _outrefs
    return @outrefs;
 }
 
-package Devel::MAT::SV::PADNAMES 0.46;
+package Devel::MAT::SV::PADNAMES 0.47;
 # Synthetic type
 use base qw( Devel::MAT::SV::ARRAY );
 use constant type => "PADNAMES";
@@ -1249,7 +1250,7 @@ sub _outrefs
    return @outrefs;
 }
 
-package Devel::MAT::SV::PAD 0.46;
+package Devel::MAT::SV::PAD 0.47;
 # Synthetic type
 use base qw( Devel::MAT::SV::ARRAY );
 use constant type => "PAD";
@@ -1359,7 +1360,7 @@ sub _outrefs
    return @outrefs;
 }
 
-package Devel::MAT::SV::HASH 0.46;
+package Devel::MAT::SV::HASH 0.47;
 use base qw( Devel::MAT::SV );
 __PACKAGE__->register_type( 5 );
 use constant $CONSTANTS;
@@ -1540,7 +1541,7 @@ sub _outrefs
    return @outrefs;
 }
 
-package Devel::MAT::SV::STASH 0.46;
+package Devel::MAT::SV::STASH 0.47;
 use base qw( Devel::MAT::SV::HASH );
 __PACKAGE__->register_type( 6 );
 use constant $CONSTANTS;
@@ -1679,7 +1680,7 @@ sub _outrefs
    return @outrefs;
 }
 
-package Devel::MAT::SV::CODE 0.46;
+package Devel::MAT::SV::CODE 0.47;
 use base qw( Devel::MAT::SV );
 __PACKAGE__->register_type( 7 );
 use constant $CONSTANTS;
@@ -2234,7 +2235,7 @@ sub _outrefs
    return @outrefs;
 }
 
-package Devel::MAT::SV::IO 0.46;
+package Devel::MAT::SV::IO 0.47;
 use base qw( Devel::MAT::SV );
 __PACKAGE__->register_type( 8 );
 use constant $CONSTANTS;
@@ -2308,7 +2309,7 @@ sub _outrefs
    return @outrefs;
 }
 
-package Devel::MAT::SV::LVALUE 0.46;
+package Devel::MAT::SV::LVALUE 0.47;
 use base qw( Devel::MAT::SV );
 __PACKAGE__->register_type( 9 );
 use constant $CONSTANTS;
@@ -2349,7 +2350,7 @@ sub _outrefs
    return @outrefs;
 }
 
-package Devel::MAT::SV::REGEXP 0.46;
+package Devel::MAT::SV::REGEXP 0.47;
 use base qw( Devel::MAT::SV );
 use constant basetype => "REGEXP";
 __PACKAGE__->register_type( 10 );
@@ -2360,7 +2361,7 @@ sub desc { "REGEXP()" }
 
 sub _outrefs { () }
 
-package Devel::MAT::SV::FORMAT 0.46;
+package Devel::MAT::SV::FORMAT 0.47;
 use base qw( Devel::MAT::SV );
 use constant basetype => "PVFM";
 __PACKAGE__->register_type( 11 );
@@ -2371,7 +2372,7 @@ sub desc { "FORMAT()" }
 
 sub _outrefs { () }
 
-package Devel::MAT::SV::INVLIST 0.46;
+package Devel::MAT::SV::INVLIST 0.47;
 use base qw( Devel::MAT::SV );
 use constant basetype => "INVLIST";
 __PACKAGE__->register_type( 12 );
@@ -2383,7 +2384,7 @@ sub desc { "INVLIST()" }
 sub _outrefs { () }
 
 # A hack to compress files
-package Devel::MAT::SV::_UNDEFSV 0.46;
+package Devel::MAT::SV::_UNDEFSV 0.47;
 use base qw( Devel::MAT::SV::SCALAR );
 __PACKAGE__->register_type( 13 );
 
@@ -2399,7 +2400,7 @@ sub load
    );
 }
 
-package Devel::MAT::SV::_YESSV 0.46;
+package Devel::MAT::SV::_YESSV 0.47;
 use base qw( Devel::MAT::SV::BOOL );
 __PACKAGE__->register_type( 14 );
 
@@ -2415,7 +2416,7 @@ sub load
    );
 }
 
-package Devel::MAT::SV::_NOSV 0.46;
+package Devel::MAT::SV::_NOSV 0.47;
 use base qw( Devel::MAT::SV::BOOL );
 __PACKAGE__->register_type( 15 );
 
@@ -2433,7 +2434,7 @@ sub load
 
 # A "SV" type that isn't really an SV, but has many of the same methods. These
 # aren't created by core perl, but are used by XS extensions
-package Devel::MAT::SV::C_STRUCT 0.46;
+package Devel::MAT::SV::C_STRUCT 0.47;
 use base qw( Devel::MAT::SV );
 __PACKAGE__->register_type( 0x7F );
 use constant $CONSTANTS;
